pub struct ScriptedTasks { /* private fields */ }Expand description
Answers each task from its own queue of JSON documents.
Implementations
Sourceimpl ScriptedTasks
impl ScriptedTasks
Sourcepub fn new(provider: impl Into<ProviderKey>, model: impl Into<ModelKey>) -> Self
pub fn new(provider: impl Into<ProviderKey>, model: impl Into<ModelKey>) -> Self
A provider with native schema support and no answers yet.
Sourcepub fn answer(self, task: &str, answer: Value) -> Self
pub fn answer(self, task: &str, answer: Value) -> Self
Queues answer for the task or call task.
Sourcepub fn failing(self, task: &str, error: ProviderError) -> Self
pub fn failing(self, task: &str, error: ProviderError) -> Self
Queues a provider failure for the task or call task.
Sourcepub fn tagged(self, tag: impl Into<String>) -> Self
pub fn tagged(self, tag: impl Into<String>) -> Self
Adds a tag to the profile, for routing by tag.
Sourcepub fn calls(&self) -> Vec<ModelRequest>
pub fn calls(&self) -> Vec<ModelRequest>
Every request received, in order.
Sourcepub fn unanswered(&self) -> Vec<String>
pub fn unanswered(&self) -> Vec<String>
Tasks with answers never asked for.